@@ -1,5 +1,15 @@
-test_that("connects and disconnects to duckdb", {
-  con <- starwars_connect()
+test_that("connects and disconnects to duckdb in memory", {
+  con <- starwars_connect(dbdir = ":memory:")
+  expect_equal(con@driver@dbdir, ":memory:")
+  expect_setequal(DBI::dbListTables(con), names(starwarsdb_tables()))
+  expect_true(inherits(con, "duckdb_connection"))
+  expect_true(DBI::dbIsValid(con))
+  starwars_disconnect(con)
+  expect_false(DBI::dbIsValid(con))
+})
+
+test_that("connects and disconnects to duckdb using dbdir file", {
+  con <- starwars_connect(dbdir = starwars_db())
   db_file <- con@driver@dbdir
   expect_true(inherits(con, "duckdb_connection"))
   expect_true(basename(db_file) == "starwars.duckdb")
